@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2015-2021 Rumma & Ko Ltd
+# Copyright 2015-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -25,7 +25,7 @@ from lino_xl.lib.cal.roles import CalendarReader
 from lino_xl.lib.votes.roles import VotesStaff, VotesUser
 from lino_xl.lib.products.roles import ProductsStaff
 from lino_xl.lib.ledger.roles import LedgerStaff
-from lino_xl.lib.orders.roles import OrdersUser, OrdersStaff
+from lino_xl.lib.invoicing.roles import InvoicingUser, InvoicingStaff
 
 from lino.modlib.users.choicelists import UserTypes
 
@@ -34,22 +34,21 @@ class Customer(SiteUser, OfficeUser, VotesUser, Searcher, Reporter, CommentsUser
     """
     A **Customer** is somebody who uses our software and may report
     tickets, but won't work on them. Able to comment and view tickets on sites
-    where they are contact people. Unable to see any client data other than orgs
-    where they are a contact person and themselves.
+    they are member of. Unable to see any contact data of other users or partners.
     """
     pass
 
 
 class Contributor(Customer, Searcher, Helper, Worker, ExcerptsUser, CoursesUser):
     """
-    A **Contributor** is somebody who works on and see tickets of sites they are team members of.
+    A **Contributor** is somebody who works on tickets of sites they are team members of.
     """
     pass
 
 
 class Developer(Contributor, Expert, ContactsUser, Triager, ExcerptsStaff, CommentsStaff, TicketsStaff, PrivateCommentsReader):
     """
-    A **Developer** is a trusted user who has signed an NDA, has access to client contacts.
+    A **Developer** is a trusted user who has signed an NDA. Has access to client contacts.
     Is able to make service reports as well as manage tickets.
     """
     pass
@@ -57,7 +56,7 @@ class Developer(Contributor, Expert, ContactsUser, Triager, ExcerptsStaff, Comme
 
 class SiteAdmin(
     SiteAdmin, Developer, OfficeStaff, VotesStaff, ContactsStaff,
-    CommentsStaff, ProductsStaff, LedgerStaff, OrdersStaff):
+    CommentsStaff, ProductsStaff, LedgerStaff, InvoicingStaff):
     """
     Can do everything.
     """
@@ -76,12 +75,3 @@ add('100', _("Customer"), Customer, 'customer user')
 add('200', _("Contributor"), Contributor, 'contributor')
 add('400', _("Developer"), Developer, 'developer')
 add('900', _("Administrator"), SiteAdmin, 'admin')
-
-# UserTypes.user = UserTypes.customer
-
-# from lino.core.merge import MergeAction
-# from lino.api import rt
-# lib = rt.models
-# for m in (lib.contacts.Company, ):
-#     m.define_action(merge_row=MergeAction(
-#         m, required_roles=set([ContactsStaff])))
