@@ -188,7 +188,8 @@ class Ticket(Ticket, Assignable, SummarizedFromSession, Hierarchical, ElasticSea
         return _("{user} modified {what}").format(**ctx)
 
     def get_change_body(self, ar, cw):
-        ctx = dict(user=ar.user, what=self.obj2memo())
+        # ctx = dict(user=ar.user, what=self.obj2memo())
+        ctx = dict(user=ar.user, what=ar.obj2htmls(self))
         if cw is None:
             elems = [E.p(
                 _("{user} submitted ticket {what}").format(**ctx), ".")]
